@@ -6,16 +6,31 @@
 Необходимость данного шаблона обусловлена спецификой реализации
 template-loaders в django.
 """
-
-from os.path import join as join_path, dirname
-
-from django.conf import settings
-from django.template import TemplateDoesNotExist
-from django.utils._os import safe_join
-from django.core.exceptions import SuspiciousOperation
-from m3_django_compat import BaseLoader
+import os
+from os.path import (
+    dirname,
+    join as join_path,
+)
 import six
 
+from django.conf import (
+    settings,
+)
+from django.core.exceptions import (
+    SuspiciousOperation,
+)
+from django.template import (
+    Origin,
+    TemplateDoesNotExist,
+)
+from django.utils._os import (
+    safe_join,
+)
+
+from m3_django_compat import (
+    BaseLoader,
+)
+
 
 # At compile time, cache the directories to search.
 module_dir = dirname(__file__)
@@ -66,9 +81,29 @@ class Loader(BaseLoader):
 
     is_usable = True
 
+    # TODO удалить после окончания поддержки Django < 2.0
     def load_template_source(self, template_name, template_dirs=None):
         return load_template_source(template_name, template_dirs)
 
+    def get_template_sources(self, template_name):
+        """
+        Возвращает объект Origin для каждого найденного шаблона.
+        """
+        origins = []
+        template_paths = get_template_sources(template_name)
+
+        for template_path in template_paths:
+            if os.path.isfile(template_path):
+                origins.append(
+                    Origin(
+                        name=template_path,
+                        template_name=template_name,
+                        loader=self,
+                    )
+                )
+
+        return origins
+
 
 def load_template_source(template_name, template_dirs=None):
     for filepath in get_template_sources(template_name, template_dirs):
